AbstractSelectWidget | django_cradmin API Document

    import AbstractSelectWidget from 'django_cradmin/scripts/django_cradmin/widgets/AbstractSelectWidget.jsx'

public class | source

# AbstractSelectWidget

#### Extends:

ievv_jsbase/widget/AbstractWidget~AbstractWidget → AbstractSelectWidget

## Constructor Summary

Public Constructor
public | constructor(element: *, widgetInstanceId: *) |

## Member Summary

Public Members
public | initialValue: * |
public | logger: * |
public | selectedValue: * |

## Method Summary

Public Methods
public | addReactWrapperElementToDocument(reactWrapperElement: *) |
public | destroy() |
public | getDefaultConfig(): * |
public | initializeReactComponent() |
public | makeReactComponentProps(): * |
public | makeReactElement() |
public | onSearchRequestedSignal(receivedSignalInfo: *) |
public | onSelectResultSignal(receivedSignalInfo: *) |
public | requestSearchResults(searchString: string): * |
public | sendSearchCompletedSignal(results: *) |

## Public Constructors

### public constructor(element: *, widgetInstanceId: *) source

#### Params:

Name | Type | Attribute | Description
element | * |  |
widgetInstanceId | * |  |

## Public Members

### public initialValue: * source

### public logger: * source

### public selectedValue: * source

## Public Methods

### public addReactWrapperElementToDocument(reactWrapperElement: *) source

#### Params:

Name | Type | Attribute | Description
reactWrapperElement | * |  |

### public destroy() source

### public getDefaultConfig(): * source

#### Return:

*

### public initializeReactComponent() source

### public makeReactComponentProps(): * source

#### Return:

*

### public makeReactElement() source

### public onSearchRequestedSignal(receivedSignalInfo: *) source

#### Params:

Name | Type | Attribute | Description
receivedSignalInfo | * |  |

### public onSelectResultSignal(receivedSignalInfo: *) source

#### Params:

Name | Type | Attribute | Description
receivedSignalInfo | * |  |

### public requestSearchResults(searchString: string): * source

#### Params:

Name | Type | Attribute | Description
searchString | string | optional default: |

#### Return:

*

### public sendSearchCompletedSignal(results: *) source

#### Params:

Name | Type | Attribute | Description
results | * |  |